@@ -3,6 +3,7 @@ import os
 import requests
 
 from maitai._config_listener_thread import ConfigListenerThread
+from maitai_common.version import version
 from maitai_common.config import config_service
 from maitai_gen.application import Application
 from maitai_gen.chat import ChatCompletionAuth
@@ -30,9 +31,12 @@ class Config:
     def api_key(self):
         if self._api_key is None:
             if self.initialized:
-                raise ValueError("Maitai API Key has not been set")
+                raise ValueError("Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY.")
             else:
-                self.initialize(api_key=os.environ.get("MAITAI_API_KEY"))
+                api_key = os.environ.get("MAITAI_API_KEY")
+                if not api_key:
+                    raise ValueError("Maitai API Key has not been set. Either pass it directly into the client, or by setting the environment variable MAITAI_API_KEY.")
+                self.initialize(api_key=api_key)
         return self._api_key
 
     @api_key.setter
@@ -57,10 +61,15 @@ class Config:
         url = f'{host}/company/'
         headers = {
             'Content-Type': 'application/json',
-            'x-api-key': self.api_key
+            'x-api-key': self.api_key,
+            'x-client-version': version,
         }
 
-        response = requests.get(url, headers=headers, verify=False)
+        response = requests.get(url, headers=headers)
+        if response.status_code != 200:
+            print(f"Failed to initialize API client. Status code: {response.status_code}. Error: {response.text}")
+            return
+
         self._company_id = response.json().get("id")
 
     def refresh_applications(self):
@@ -68,10 +77,14 @@ class Config:
         url = f'{host}/application/'
         headers = {
             'Content-Type': 'application/json',
-            'x-api-key': self.api_key
+            'x-api-key': self.api_key,
+            'x-client-version': version,
         }
 
-        response = requests.get(url, headers=headers, verify=False)
+        response = requests.get(url, headers=headers)
+        if response.status_code != 200:
+            print(f"Failed to initialize API client. Status code: {response.status_code}. Error: {response.text}")
+            return
         applications = [Application().from_dict(app_json) for app_json in response.json()]
         for application in applications:
             self._applications[application.application_ref_name] = application
